using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Media;
using Microsoft.Xna.Framework.Net;
using Microsoft.Xna.Framework.Storage;

namespace HeHathNoFury
{
    /// <summary>
    /// This is the main type for your game
    /// </summary>
    public class Game1 : Microsoft.Xna.Framework.Game
    {
        GraphicsDeviceManager graphics;
        private SpriteBatch spriteBatch = null;
        private int lastTickCount;
        private int eCount;
        private const int TIME = 1000;
        private SpriteFont gFont;

        protected HelpScene hscene;                                 // help menu
        protected GameScene ascene;                                 // game menu
        protected MainScene scene;                                  // title scene
        protected Texture2D mainbg, mainfg;                         // for title screen
        protected Texture2D helpgb, helpfg;                         // for help menu

        private Song bMusic;                                        // background music
        private Texture2D bgTexture;                                // 1st background
        private Texture2D bossBG;                                   // boss background
        protected Texture2D abbg, abfg;
        private Texture2D fLoor;                                    // floor of game
        private pLayer player;                                      // declare plAYER attr.
        private Texture2D hero;                                     // player sprite
        private Texture2D eNemy;                                    // common foe
        private Texture2D boss;                                     // demo boss


        public Game1()
        {
            graphics = new GraphicsDeviceManager(this);
            Content.RootDirectory = "Content";

            graphics.PreferredBackBufferWidth = 1280;
            graphics.PreferredBackBufferHeight = 720;


#if XBOX360
    // On the 360, we are always fullscreen and we always render to the user's 
    // prefered resolution
            graphics.PreferredBackBufferWidth = this.Window.ClientBounds.Width;
            graphics.PreferredBackBufferHeight = this.Window.ClientBounds.Height;
            // We also get multisampling essentially for free on the 360, 
            // so turn it on
            graphics.PreferMultiSampling = true;
#endif
         
        }

        /// <summary>
        /// Allows the game to perform any initialization it needs to before starting to run.
        /// This is where it can query for any required services and load any non-graphic
        /// related content.  Calling base.Initialize will enumerate through any components
        /// and initialize them as well.
        /// </summary>
        protected override void Initialize()
        {
            base.Initialize();
            Window.Title = "Artful Dodger";
        }

        /// <summary>
        /// LoadContent will be called once per game and is the place to load
        /// all of your content.
        /// </summary>
        protected override void LoadContent()
        {
           
            // Create a new SpriteBatch, which can be used to draw textures.
            spriteBatch = new SpriteBatch(graphics.GraphicsDevice);
            // adding service
            Services.AddService(typeof(SpriteBatch), spriteBatch);
            
            helpgb = Content.Load<Texture2D>(@"images\backgrounds\bgboss");
            helpfg = Content.Load<Texture2D>(@"images\backgrounds\help");

            hscene = new HelpScene(this, helpgb, helpfg);
            Components.Add(hscene);
            //hscene.Show();

            bgTexture = Content.Load<Texture2D>(@"images\backgrounds\gamebgoutside");
            bossBG = Content.Load<Texture2D>(@"images\backgrounds\bginside");
            fLoor = Content.Load<Texture2D>(@"images\backgrounds\floor");
            hero = Content.Load<Texture2D>(@"images\sprites\user\hero1");
            eNemy = Content.Load<Texture2D>(@"images\sprites\auto\enemy1-1");
            boss = Content.Load<Texture2D>(@"images\sprites\auto\boss");
            gFont = Content.Load<SpriteFont>("font");
            bMusic = Content.Load<Song>("Robot rock");
            MediaPlayer.Play(bMusic);

        }

        /// <summary>
        /// UnloadContent will be called once per game and is the place to unload
        /// all content.
        /// </summary>
        protected override void UnloadContent()
        {
            // TODO: Unload any non ContentManager content here
        }

        /// <summary>
        /// Allows the game to run logic such as updating the world,
        /// checking for collisions, gathering input, and playing audio.
        /// </summary>
        /// <param name="gameTime">Provides a snapshot of timing values.</param>
        protected override void Update(GameTime gameTime)
        {

            // Allows the game to exit
            if ((GamePad.GetState(PlayerIndex.One).Buttons.Back == ButtonState.Pressed) || (Keyboard.GetState().IsKeyDown(Keys.Escape)))
            {
                Exit();
            }

            // start if not started yet
            if (player == null)
            {
                Start();
            }

            DoGameLogic();

            base.Update(gameTime);
        }

        /// <summary>
        /// This is called when the game should draw itself.
        /// </summary>
        /// <param name="gameTime">Provides a snapshot of timing values.</param>
        protected override void Draw(GameTime gameTime)
        {
            GraphicsDevice.Clear(Color.CornflowerBlue);

            // TODO: Add your drawing code here
            spriteBatch.Begin();
            spriteBatch.Draw(bossBG, new Rectangle(0, 0, graphics.GraphicsDevice.DisplayMode.Width, graphics.GraphicsDevice.DisplayMode.Height), Color.White);
            spriteBatch.Draw(fLoor, new Rectangle(0, 0, 1280, 720), Color.White);
            spriteBatch.End();

            spriteBatch.Begin(SpriteBlendMode.AlphaBlend);
            base.Draw(gameTime);
            spriteBatch.End();

            spriteBatch.Begin();
            spriteBatch.DrawString(gFont, "Time: " + eCount.ToString(), new Vector2(25, 25), Color.YellowGreen);
            spriteBatch.End();
            
        }
        
        // initialize game round
        private void Start()
        {
            //create and put player in start position
            if (player == null)
            {
                player = new pLayer(this, ref hero);
                Components.Add(player);
            }
            player.StartPosition();

            // adds enemies
            for (int i = 0; i < 1; i++)
            {
                Components.Add(new enemy(this, ref eNemy));
            }

            //initiate counter
            lastTickCount = System.Environment.TickCount;

            // reset enemy count
            eCount = 1;



        }

        // run game logic
        private void DoGameLogic()
        {
            //check collisions
            bool hasCol = false;
            Rectangle heroR = player.GetBounds();
            foreach (GameComponent gc in Components)
            {
                if (gc is enemy)
                {
                    hasCol = ((enemy)gc).CheckCollision(heroR);
                    if (hasCol)
                    {
                        // Remove all previous enemies
                        RemoveAllEnemies();
                        Start();

                        break;
                    }
                }
            }

            AddNewEnemy();
        }

        // remove enemies
        private void RemoveAllEnemies()
        {
            for (int i = 0; i < Components.Count; i++)
            {
                if (Components[i] is enemy)
                {
                    Components.RemoveAt(i);
                    i--;
                }
            }
        }

        private void AddNewEnemy()
        {
            if ((System.Environment.TickCount - lastTickCount) > TIME)
            {
                lastTickCount = System.Environment.TickCount;
                Components.Add(new enemy(this, ref eNemy));
                eCount++;
            }
        }
    }
}