#region Using Statements
using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Media;
using Microsoft.Xna.Framework.Net;
using Microsoft.Xna.Framework.Storage;
#endregion

namespace HeHathNoFury
{
    /// <summary>
    /// This is a game component that implements IUpdateable.
    /// </summary>
    public class pLayer : DrawableGameComponent
    {
        protected Texture2D Player1;
        protected Rectangle pBorder;
        protected Vector2 pos;

        // width and height of player sprite
        protected const int PWIDTH = 88;
        protected const int PHEIGHT = 108;

        //screen area
        protected Rectangle sBounds;

        public pLayer(Game game, ref Texture2D tPlayer)
            : base(game)
        {
            Player1 = tPlayer;
            pos = new Vector2();
            pBorder = new Rectangle(0, 0, PWIDTH, PHEIGHT);

#if XBOX360
            sBounds = new Rectangle((int)(Game.Window.ClientBounds.Width * 0.03f),
                (int)(Game.Window.ClientBounds.Height * 0.03f), Game.Window.ClientBounds.Width-(int)(Game.Window.ClientBounds.Width * 0.03f),
                Game.Window.ClientBounds.Height - (int)(Game.Window.ClientBounds.Height * 0.03f));
#else
            sBounds = new Rectangle (0, 0, Game.Window.ClientBounds.Width, game.Window.ClientBounds.Height);
#endif
        }

        public void StartPosition()                                                         // start position for player
        {
            pos.X = -(sBounds.Width - PWIDTH);
            pos.Y = sBounds.Height - 20 - PHEIGHT;
        }

        
        /// <summary>
        /// Allows the game component to perform any initialization it needs to before starting
        /// to run.  This is where it can query for any required services and load content.
        /// </summary>
        public override void Initialize()
        {
            // TODO: Add your initialization code here

            base.Initialize();
        }

        /// <summary>
        /// updates player position
        /// </summary>
        /// <param name="gameTime">Provides a snapshot of timing values.</param>
        public override void Update(GameTime gameTime)
        {
            // with 360 remote
            GamePadState gpStatus = GamePad.GetState(PlayerIndex.One);
            pos.Y += (int)((gpStatus.ThumbSticks.Left.Y * 3) * -2);
            pos.X += (int)((gpStatus.ThumbSticks.Left.X * 3) * 2);

            // with keyboard
            KeyboardState kBoard = Keyboard.GetState();
            if (kBoard.IsKeyDown(Keys.Up))
            {
                pos.Y -= 3;
            }
            if (kBoard.IsKeyDown(Keys.Down))
            {
                pos.Y += 3;
            }
            if (kBoard.IsKeyDown(Keys.Left))
            {
                pos.X -= 3;
            }
            if (kBoard.IsKeyDown(Keys.Right))
            {
                pos.X += 3;
            }

            // keep player on floor
            if (pos.X < sBounds.Left)
            {
                pos.X = sBounds.Left;
            }
            if (pos.X > sBounds.Width - PWIDTH)
            {
                pos.X = sBounds.Width - PWIDTH;
            }
            if (pos.Y < sBounds.Height *2/3)
            {
                pos.Y = sBounds.Height*2/3;
            }
            if (pos.Y > sBounds.Height - PHEIGHT)
            {
                pos.Y = sBounds.Height - PHEIGHT;
            }

            base.Update(gameTime);
        }

        /// <summary>
        /// Draws the player
        /// </summary>
        public override void Draw(GameTime gameTime)
        {
            //get current sprite batch
            SpriteBatch sBatch = (SpriteBatch)Game.Services.GetService(typeof(SpriteBatch));

            // draw ship
            sBatch.Draw(Player1, pos, pBorder, Color.White);

            base.Draw(gameTime);
        }

        /// <summary>
        /// get bound rect. of player position in screen
        /// </summary>
        public Rectangle GetBounds()
        {
            return new Rectangle((int)pos.X, (int)pos.Y, PWIDTH, PHEIGHT);
        }
    }
}